==> BetterMod-1.7.22-sources.jar: com/techteam/fabric/bettermod/impl/block/entity/BetterExtractingHopperBlockEntity.java <==
package com.techteam.fabric.bettermod.impl.block.entity;

import com.techteam.fabric.bettermod.impl.util.InventoryUtil;
import net.fabricmc.fabric.api.lookup.v1.block.BlockApiCache;
import net.fabricmc.fabric.api.transfer.v1.item.ItemStorage;
import net.fabricmc.fabric.api.transfer.v1.item.ItemVariant;
import net.fabricmc.fabric.api.transfer.v1.storage.Storage;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import org.jetbrains.annotations.NotNull;

public abstract class BetterExtractingHopperBlockEntity<T extends BetterExtractingHopperBlockEntity<T>> extends BetterHopperBlockEntity<T> {
	protected BlockApiCache<Storage<ItemVariant>, class_2350> PULL_TARGET_CACHE;

	public BetterExtractingHopperBlockEntity(class_2591<T> blockEntityType, @NotNull class_2338 blockPos, class_2680 blockState) {
		super(blockEntityType, blockPos, blockState);
	}

	public boolean extract() {
		Storage<ItemVariant> PULL_TARGET = PULL_TARGET_CACHE.find(class_2350.field_11033);
		if (PULL_TARGET != null) {
			return InventoryUtil.handleTransferStackable(PULL_TARGET, SELF);
		}
		return false;
	}

	@Override
	public void method_31662(class_1937 world) {
		super.method_31662(world);
		if (world instanceof class_3218 serverWorld) {
			PULL_TARGET_CACHE = BlockApiCache.create(ItemStorage.SIDED, serverWorld, field_11867.method_10084());
		}
	}

	public boolean isFull() {
		return false;
	}

	@Override
	public void scheduledTick(class_1937 world, class_2338 pos, class_2680 blockState) {
		boolean activated = false;
		if (!method_5442()) {
			activated = this.insert();
		}

		if (!isFull()) {
			activated |= this.extract();
		}

		if (activated) {
			setCooldown(BetterHopperBlockEntity.MAX_COOLDOWN, false);
		}
	}
}

==> BetterMod-1.7.24-sources.jar: com/techteam/fabric/bettermod/impl/block/entity/BetterExtractingHopperBlockEntity.java <==
package com.techteam.fabric.bettermod.impl.block.entity;

import com.techteam.fabric.bettermod.impl.util.InventoryUtil;
import net.fabricmc.fabric.api.lookup.v1.block.BlockApiCache;
import net.fabricmc.fabric.api.transfer.v1.item.ItemStorage;
import net.fabricmc.fabric.api.transfer.v1.item.ItemVariant;
import net.fabricmc.fabric.api.transfer.v1.storage.Storage;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import org.jetbrains.annotations.NotNull;

public abstract class BetterExtractingHopperBlockEntity<T extends BetterExtractingHopperBlockEntity<T>> extends BetterHopperBlockEntity<T> {
	protected BlockApiCache<Storage<ItemVariant>, class_2350> PULL_TARGET_CACHE;

	public BetterExtractingHopperBlockEntity(class_2591<T> blockEntityType, @NotNull class_2338 blockPos, class_2680 blockState) {
		super(blockEntityType, blockPos, blockState);
	}

	public boolean extract() {
		Storage<ItemVariant> PULL_TARGET = PULL_TARGET_CACHE.find(class_2350.field_11033);
		if (PULL_TARGET != null) {
			return InventoryUtil.handleTransfer(PULL_TARGET, SELF);
		}
		return false;
	}

	@Override
	public void method_31662(class_1937 world) {
		super.method_31662(world);
		if (world instanceof class_3218 serverWorld) {
			PULL_TARGET_CACHE = BlockApiCache.create(ItemStorage.SIDED, serverWorld, field_11867.method_10084());
		}
	}

	public boolean isFull() {
		return false;
	}

	@Override
	public void scheduledTick(class_1937 world, class_2338 pos, class_2680 blockState) {
		boolean activated = false;
		if (!method_5442()) {
			activated = this.insert();
		}

		if (!isFull()) {
			activated |= this.extract();
		}

		if (activated) {
			setCooldown(BetterHopperBlockEntity.MAX_COOLDOWN, false);
		}
	}
}
